import Avatar from "../db/Avatar";
import Logger from "../util/Logger";
import Interface, { Command } from "./Interface";
import Session from "../server/kcp/Session";
import AvatarConfig from "../util/excel/AvatarConfig";
const c = new Logger("/avatar", "blue");

export default async function handle(command: Command, target: Session) {
    if (!target) {
        c.log("No target specified");
        return;
    }

    const actionType = command.args[0];
    const avatarId = Number(command.args[1]);
    const uid = target.player.db._id;
    const player = target.player;
    const AvatarExcelTable = AvatarConfig.all().map(x => x.AvatarID);

    switch (actionType) {
        default: {
            c.log(`Usage: /avatar <add|remove|giveall|removeall> <avatarId>`);
            break;
        }
        case "add": {
            if (!avatarId) {
                return c.log("No avatarId specified");
            }

            // Check if it already exists
            if (await Avatar.hasAvatar(player, avatarId)) {
                return c.log(`Avatar ${avatarId} already exists`);
            }

            await Avatar.addAvatar(player, avatarId).then(a => c.log(`Avatar ${avatarId} added to ${a.ownerUid}`));
            break;
        }
        case "remove": {
            if (!avatarId) return c.log("No avatarId specified");
            await Avatar.removeAvatar(player, avatarId).then(() => c.log(`Avatar ${avatarId} removed from ${uid}`));
            break;
        }
        case "giveall": {
            for (const id of AvatarExcelTable) {
                // Let's not brick our account.
                if (id >= 8000) continue;
                if (await Avatar.hasAvatar(player, id)) continue;
                
                await Avatar.addAvatar(player, id);
            }
            c.log(`All avatars added to ${uid}`);
            break;
        }
        case "removeall": {
            for (const id of AvatarExcelTable) {
                if (id != 1001) await Avatar.removeAvatar(player, id);
            }
            c.log(`All avatars removed from ${uid}`);
            break;
        }
    }

    target.sync();
}
