import { BattleAvatar, BattleBuff, HeroPath, Item, ItemList, SceneBattleInfo, SceneEnterStageScRsp, SceneMonsterWave, StartCocoonStageScRsp } from "../data/proto/StarRail";
import Avatar from "../db/Avatar";
import Inventory from "../db/Inventory";
import Session from "../server/kcp/Session";
import MazePlane from "../util/excel/MazePlane";
import Logger from "../util/Logger";
import Interface, { Command } from "./Interface";
const c = new Logger("/battle", "blue");

export default async function handle(command: Command, target: Session) {
    if (!target) {
        c.log("No target specified");
        return;
    }

    if (command.args.length == 0) {
        c.log("Usage: /battle <monsterId>+");
        return;
    }

    const player = target.player;
    const maze = MazePlane.fromPlaneId(player.db.posData.planeID);
    if (maze?.PlaneType !== "Maze") {
        c.log("For now, this is only confirmed to work on MazeType Maze, please teleport there first.");
    }

    const inventory = await player.getInventory();
    const avatars = await Avatar.getAvatarsForLineup(player, player.db.lineup.lineups[player.db.lineup.curIndex]);
    const monsters = command.args.map(arg => Number(arg));

    target.send(SceneEnterStageScRsp, {
        retcode: 0,
        // propEntityId: 0,
        // cocoonId: 1001,
        // wave: 0,
        battleInfo: {
            worldLevel: target.player.db.basicInfo.worldLevel,
            mapId: 200010010,
            logicRandomSeed: 1,
            stageId: 1022010,
            monsterWaveList: [
                {
                    monsterIdList: monsters,
                    monsterParam: {},
                    dropList: Array(monsters.length).fill({ itemList: [{ itemId: 102, num: 10 }] }),
                    monsterList: monsters.map(x => {
                        return {
                            monsterId: x
                        }
                    })
                } as SceneMonsterWave
            ],
            battleAvatarList: avatars.map((avatar, i) => {
                const equipment = inventory.equipments.find(x => x.uniqueId === avatar.equipmentUniqueId);
                const equipData = (equipment) ? [{
                    id: equipment.tid,
                    level: equipment.level,
                    promotion: equipment.promotion,
                    rank: equipment.rank
                }] : [];

                return {
                    avatarType: avatar.avatarType,
                    equipmentList: equipData,
                    hp: avatar.fightProps.hp,
                    id: avatar.baseAvatarId,
                    sp: avatar.fightProps.sp,
                    index: i,
                    level: avatar.level,
                    promotion: avatar.promotion,
                    rank: avatar.rank,
                    relicList: [],
                    skilltreeList: []
                };
            }),
            buffList: new Array<BattleBuff>(),
            battleId: target.player.scene.battleId++, // Increasing
            // heroPathList: new Array<HeroPath>(),
            // roundsLimit: 100
        }
    });
}