import { Equipment } from "../data/proto/StarRail";
import Player from "../game/Player";
import Session from "../server/kcp/Session";
import EquipmentConfig from "../util/excel/EquipmentConfig";
import ItemConfig from "../util/excel/ItemConfig";
import Logger from "../util/Logger";
import Interface, { Command } from "./Interface";
const c = new Logger("/item", "blue");

export default async function handle(command: Command, target: Session) {
    if (!target) {
        c.log("No target specified");
        return;
    }

    const player = target.player;
    const actionType = command.args[0];
    const itemId = Number(command.args[1]);
    const giveAllType = command.args[1] ?? "All";

    let count: number = 1;
    let level: number = 1;
    let rank: number = 1;
    let promotion: number = 0;

    for (let i = 2; i < command.args.length; i++) {
        const arg = command.args[i];
        const number = Number(command.args[i].substring(1));

        switch (arg[0]) {
            case "x":
                count = number;
                break;
            case "l":
                level = number;
                break;
            case "r":
                rank = number;
                break;
            case "p":
                promotion = number;
                break;
        }
    }

    switch (actionType) {
        case "give": {
            await handleGive(player, itemId, count, level, rank, promotion);
            break;
        }
        case "giveall": {
            await handleGiveAll(player, giveAllType);
            break;
        }
        case "clear": {
            const inventory = await player.getInventory();
            inventory.materials = [];
            inventory.relics = [];
            inventory.equipments = [];
            await inventory.save();
            break;
        }
        default: {
            c.log(`Usage: /item <give|giveall|clear> <itemId> [x<count>|l<level>|r<rank>|p<promotion>]*`);
            return;
        }
    }

    // Sync session.
    await player.session.sync();
}

async function handleGive(player: Player, itemId: number, count: number = 1, level: number = 1, rank: number = 1, promotion: number = 1) {
    if (!itemId) {
        return c.log("No avatarId specified");
    }

    // Check if this item exists.
    const itemData = ItemConfig.fromId(itemId);
    const equipData = EquipmentConfig.fromId(itemId);
    if (!itemData && !equipData) {
        return c.log(`Item ID ${itemId} does not exist.`);
    }

    const inventory = await player.getInventory();
    let succ = false;

    switch ((itemData?.ItemMainType) ?? "Equipment") {
        case "Equipment":
            for (let i = 0; i < count; i++) {
                succ = await inventory.addEquipment(itemId, count, level, rank, promotion);
            }
            break;
        default:
            // return c.log(`Unsupported item type: ${itemData.ItemMainType}.`);
            succ = await inventory.addItem(itemId, count, player);
            break;
    }

    succ ? c.log(`Added ${count} of item ${itemId} to player ${player.uid}`) : c.log(`Failed to add item ${itemId} to player ${player.uid}`);
}

async function handleGiveAll(player: Player, type: string = "All") {
    const inventory = await player.getInventory();

    const query = type === "All" ? ItemConfig.all() : ItemConfig.all().filter(e => e.ItemMainType === type);

    for (const entry of query) {
        let count = 1;
        switch (entry.ItemMainType) {
            case "Material":
                count = 5000;
                break;
            case "Virtual":
                count = 10_000_000;
                break;
        }

        await inventory.addItem(entry.ID, count, player);
    }

    await inventory.save();
    c.log(`All materials added to ${player.uid}`);
}