import Avatar from "../db/Avatar";
import Session from "../server/kcp/Session";
import Logger from "../util/Logger";
import { Command } from "./Interface";
const c = new Logger("/level", "blue");

function promote(level: number) {
    switch (true) {
        case level <= 20 && level >= 1:
            return 1;
        case level <= 30 && level >= 21:
            return 2;
        case level <= 40 && level >= 31:
            return 3;
        case level <= 60 && level >= 41:
            return 4;
        case level <= 70 && level >= 61:
            return 5;
        case level >= 70:
            return 6;
        default:
            return 0;
    }
}

export default async function handle(command: Command, target: Session) {
    if (!target) return c.log("No target specified");

    const action = command.args[0];
    const aid = Number(command.args[1]);
    const level = Number(command.args[2]);
    if (isNaN(aid) || isNaN(level)) return c.log("Usage: /level <avatar|eidolon|equipment|rank> <avatarId> <level>");

    const avatar = await Avatar.getAvatar(target.player, aid);
    if (!avatar) return c.log("Avatar not found");

    const inv = await target.player.getInventory();
    const item = await inv.getEquipment(avatar.equipmentUniqueId || -1);

    switch (action) {
        case "avatar":
            avatar.level = level;
            avatar.promotion = promote(level);
            await avatar.save();
            break;
        case "equipment":
            if (!item) return c.log("Equipment not found");

            item.level = level;
            item.promotion = promote(level);
            await inv.save();
            break;
        case "eidolon":
            avatar.rank = level;
            await avatar.save();
            break;
        case "rank":
            if (!item) return c.log("Equipment not found");
            item.rank = level;
            await inv.save();
            break;
        default:
            return c.log("Usage: /level <avatar|equipment> <avatarId> <level>");
    }

    await target.sync();
    c.log(`Set ${action} ${aid} to level ${level}`);
}