import { Item, NewMailScNotify } from "../data/proto/StarRail";
import Mail from "../db/Mail";
import Player from "../db/Player";
import Session from "../server/kcp/Session";
import SRServer from "../server/kcp/SRServer";
import Logger from "../util/Logger";
import Interface, { Command } from "./Interface";
const c = new Logger("/mail", "blue");

export default async function handle(command: Command, target: Session) {
    const action = <string>command.args[0];

    if (!action) {
        c.log("Usage: /mail <title|content|sender|expire|items|send|sendall> [args|json]");
        c.log("Example: /mail title Welcome to CrepeSR!");
        c.log("Example: /mail expire 86400 (in 1 day)");
        c.log("Example: /mail items [{\"itemId\": 1102, \"num\": 1, \"level\": 80}, {\"itemId\": 102, \"num\": 10}]");
        return;
    }

    switch (action) {
        case "title":
            Interface.mailCache.title = command.args.slice(1).join(" ");
            c.log(`Title set to ${Interface.mailCache.title}`);
            break;
        case "content":
            Interface.mailCache.content = command.args.slice(1).join(" ");
            c.log(`Mail body set`);
            break;
        case "sender":
            Interface.mailCache.sender = command.args.slice(1).join(" ");
            c.log(`Sender set to ${Interface.mailCache.sender}`);
            break;
        case "expire":
            Interface.mailCache.expireTime = Date.now() / 1000 + parseInt(command.args[1]);
            c.log(`Expire time set to ${new Date(Interface.mailCache.expireTime * 1000).toLocaleString()}`);
            break;
        case "items":
            try {
                const items = JSON.parse(command.args.slice(1).join(" ")) as Item[];
                Interface.mailCache.attachments = items as any;
                c.log(`Items set to ${items.length} items: ${items.map(i => i.itemId).join(", ")}`);
            } catch (e) {
                c.error(`Invalid JSON: ${e}`, false);
                c.log(`Example: [{"itemId": 1102, "num": 1, "level": 80}, {"itemId": 102, "num": 10}]`);
            }
            break;
        case "send":
            if (!target) {
                c.log("No target specified");
                return;
            }
            const mail = await genMail(target.player.uid);
            mail.notify(target);
            break;
        case "sendall":
            const players = await (await Player.find({}).exec()).map(x => x.uid);
            
            for (const uid of players) {
                await genMail(uid);
            }

            SRServer.getInstance().broadcast(NewMailScNotify, <NewMailScNotify>{
                mailIdList: [2503]
            });
    }

    function generateRandomId(uid: number) {
        return Number(`${uid}0${Math.floor(Math.random() * 100000)}`);
    }

    async function genMail(uid: number) {
        return await Mail.create({
            toUid: uid,
            title: Interface.mailCache.title,
            body: Interface.mailCache.content,
            attachment: { itemList: Interface.mailCache.attachments },
            sender: Interface.mailCache.sender,
            expireTime: Interface.mailCache.expireTime,
            isRead: false,
            mailId: generateRandomId(uid)
        });
    }
}