import { MissionStatus, PlayerSyncScNotify } from "../data/proto/StarRail";
import Session from "../server/kcp/Session";
import Logger from "../util/Logger";
import { Command } from "./Interface";
const c = new Logger("/mission", "blue");

enum QuestCommandAction {
    Start = "start",
    State = "state",
    Finish = "finish",
}

export default async function handle(command: Command, target: Session) {
    if (!target) {
        c.log("No target specified");
        // return;
    }
    const action = command.args[0];
    const id: number = parseInt(command.args[1]);
    const params = command.args.slice(2);

    if (!action || !id || isNaN(id)) {
        c.log(`Usage: mission <${Object.keys(QuestCommandAction).map(x => x.toLowerCase()).join("|")}> <subMissionId> [params]`);
        return;
    }

    switch (action) {
        case QuestCommandAction.Start:
            c.log(`Starting quest ${id}`);
            target.send(PlayerSyncScNotify, {
                missionSync: {
                    missionList: [{
                        id,
                        progress: <any>params[0] ?? 0,
                        status: MissionStatus.MISSION_STATUS_MISSION_DOING
                    }]
                }
            });
            break;
        case QuestCommandAction.State:
            const status = MissionStatus[params[0] as keyof typeof MissionStatus];
            c.log(`Setting quest ${id} to ${status}`);
            target.send(PlayerSyncScNotify, {
                missionSync: {
                    missionList: [{
                        id,
                        progress: <any>params[1],
                        status: status
                    }]
                }
            });
            break;
        case QuestCommandAction.Finish:
            c.log(`Finishing quest ${id}`);
            target.send(PlayerSyncScNotify, {
                missionSync: {
                    missionList: [{
                        id,
                        progress: <any>params[0],
                        status: MissionStatus.MISSION_STATUS_MISSION_FINISH
                    }]
                }
            });
            break;
        default:
            // Should theoretically never happen
            c.log(`Unknown action ${action}`);
    }
}