import CmdID from "../data/proto/CmdID";
import Session from "../server/kcp/Session";
import Logger from "../util/Logger";
import ProtoFactory from "../util/ProtoFactory";
import { Command } from "./Interface";
const c = new Logger("/packet", "blue");

export default async function handle(command: Command, target: Session) {
    if (!target) {
        c.log("No target specified");
        return;
    }

    let pid = parseInt(command.args[0]);
    let body: any;

    try {
        body = JSON.parse(command.args.slice(1).join(" ") ?? "{}");
        if (isNaN(pid)) pid = CmdID[command.args[0] as keyof typeof CmdID];
        if (!pid) throw new EvalError();
    } catch {
        c.log(`Usage: /packet <CmdID> <JSON>`);
        return;
    }

    const BLACKLIST = [
        CmdID.PlayerHeartBeatScRsp, // RCE
        CmdID.ClientDownloadDataScNotify, // RCE
        CmdID.SceneEntityMoveScRsp // RCE
    ];

    if (BLACKLIST.includes(pid)) return c.log(`Packet ${pid} is blacklisted`);

    // I sometimes wonder if just ts-ignore was better
    const type = ProtoFactory.getType(CmdID[pid as unknown as keyof typeof CmdID] as unknown as Parameters<typeof ProtoFactory.getType>[0]);
    const name = ProtoFactory.getName(type);

    if (!type) {
        target.sendCmdID(pid);
        return;
    }

    await target.send(type, body);
    c.log(`Sent ${pid} (${name}) to ${target.id}`);
}