import { MissionStatus, PlayerSyncScNotify, QuestStatus } from "../data/proto/StarRail";
import Session from "../server/kcp/Session";
import Logger from "../util/Logger";
import { Command } from "./Interface";
const c = new Logger("/quest", "blue");

enum QuestCommandAction {
    Start = "start",
    State = "state",
    Finish = "finish",
}

export default async function handle(command: Command, target: Session) {
    if (!target) {
        c.log("No target specified");
        // return;
    }
    const action = command.args[0];
    const id: number = parseInt(command.args[1]);
    const params = command.args.slice(2);

    if (!action || !id || isNaN(id)) {
        c.log(`Usage: quest <${Object.keys(QuestCommandAction).map(x => x.toLowerCase()).join("|")}> <questId> [params]`);
        return;
    }

    switch (action) {
        case QuestCommandAction.Start:
            c.log(`Starting quest ${id}`);
            target.send(PlayerSyncScNotify, {
                questList: [{
                    id,
                    progress: <any>params[0] ?? 0,
                    status: QuestStatus.QUEST_STATUS_QUEST_DOING
                }]
            });
            break;
        case QuestCommandAction.State:
            const status = QuestStatus[params[0] as keyof typeof QuestStatus];
            c.log(`Setting quest ${id} to ${status}`);
            target.send(PlayerSyncScNotify, {
                questList: [{
                    id,
                    progress: <any>params[0] ?? 0,
                    status: status
                }]
            });
            break;
        case QuestCommandAction.Finish:
            c.log(`Finishing quest ${id}`);
            target.send(PlayerSyncScNotify, {
                questList: [{
                    id,
                    progress: <any>params[0] ?? 0,
                    status: QuestStatus.QUEST_STATUS_QUEST_FINISH
                }]
            });
            break;
        default:
            // Should theoretically never happen
            c.log(`Unknown action ${action}`);
    }
}