import Logger from "../util/Logger";
import { ActorEntity } from "../game/entities/Actor";
import Interface, { Command } from "./Interface";
import { GetCurSceneInfoScRsp } from "../data/proto/StarRail";
import MazePlane from "../util/excel/MazePlane";
import MapEntrance from "../util/excel/MapEntrance";
import Session from "../server/kcp/Session";
const c = new Logger("/scene", "blue");

export default async function handle(command: Command, target: Session) {
    if (!target) {
        c.log("No target specified");
        return;
    }

    const planeID = MazePlane.fromPlaneId(parseInt(command.args[0]));
    if (!planeID) return c.log("PlaneID not found.");
    let entry = MapEntrance.fromFloorId(parseInt(command.args[1]) ?? planeID.StartFloorID);
    if (!entry) entry = MapEntrance.fromFloorId(planeID.StartFloorID);
    if (!entry) return c.log("MapEntry not found.");

    const entryId = entry.ID;
    const posData = target.player.db.posData;
    const lineup2 = await target.player.getLineup();
    const curAvatarEntity = new ActorEntity(target.player.scene, lineup2.avatarList![0].id!, posData.pos);

    if (!planeID) return c.log("Usage: /scene <planeID> [floorID]");

    // Update scene information on player.
    target.player.db.posData.planeID = planeID.PlaneID;
    target.player.db.posData.floorID = planeID.StartFloorID;
    await target.player.save()

    //ty for tamilpp25 scene
    target.send(GetCurSceneInfoScRsp, {
        retcode: 0,
        scene: {
            planeId: planeID.PlaneID,
            floorId: planeID.StartFloorID,
            entityList: [
                curAvatarEntity.getSceneEntityInfo(),
                ...target.player.scene.spawnDefaultEntities(),
            ],
            entityBuffList: [],
            entryId: entryId,
            envBuffList: [],
            gameModeType: MazePlane.getGameModeForPlaneType(planeID.PlaneType),
            lightenSectionList: new Array(500).fill(0).map((_, i) => i + 1)
        },
    } as GetCurSceneInfoScRsp);

    target.player.scene.spawnEntity(curAvatarEntity, true);
    target.sync();

    c.log(`Scene set to PlaneID: ${planeID.PlaneID}`);
}
