import { AvatarType, SyncLineupNotify } from "../data/proto/StarRail";
import Session from "../server/kcp/Session";
import TrialAdventurePlayer from "../util/excel/TrialAdventurePlayer";
import Logger from "../util/Logger";
import { Command } from "./Interface";
const c = new Logger("/trial", "blue");

export default async function handle(command: Command, target: Session) {
    if (!target) {
        c.log("No target specified");
        return;
    }

    const avatarId = parseInt(command.args[0]);
    if (!avatarId || isNaN(avatarId)) {
        c.log(`Usage: /trial <avatarId>`);
        return;
    }

    const trialAdventurePlayer = TrialAdventurePlayer.fromAvatarId(avatarId);
    if (trialAdventurePlayer.length === 0) {
        c.log(`No trial adventure player found for avatarId ${avatarId}`);
        return;
    }

    // Select highest level
    const player = trialAdventurePlayer.reduce((prev, curr) => prev.Level > curr.Level ? prev : curr);

    target.send(SyncLineupNotify, {
        lineup: {
            avatarList: [{
                hp: 10000,
                sp: 9000,
                avatarType: AvatarType.AVATAR_TYPE_AVATAR_TRIAL_TYPE,
                id: player.TrialPlayerID,
            }],
            isVirtual: true,
            mp: 3,
            planeId: target.player.db.posData.planeID,
            HJJCMINJCNJ: 3 // Max technique points (?)
        }
    });

    c.log(`Added trial ${player.TrialPlayerID} (Avatar ID: ${avatarId})`);
}