import Session from "../server/kcp/Session";
import Logger from "../util/Logger";
import Whitelist from "../util/Whitelist";
import { Command } from "./Interface";
const c = new Logger("/whitelist", "blue");

export default async function handle(command: Command, target: Session) {
    const usage = "Usage: /whitelist <add|remove|list> <uid>"

    const uid = parseInt(command.args[1]);
    if (isNaN(uid) && command.args[0] !== "list") return c.log(usage);

    switch (command.args[0]) {
        case "add":
            if (command.args.length < 2) return c.log(usage);
            Whitelist.Instance.add(uid);
            c.log(`Added UID ${uid} to the whitelist`);
            break;
        case "remove":
            if (command.args.length < 2) return c.log(usage);
            Whitelist.Instance.remove(uid);
            c.log(`Removed UID ${uid} from the whitelist`);
            break;
        case "list":
            const list = Whitelist.Instance.get();
            if (list.length === 0) return c.log("There are no whitelisted players");
            c.log("Whitelisted players:");
            for (const entry of list) {
                if (entry.whitelisted) c.trail(`UID: ${entry.uid}`);
            }
            break;
        default:
            c.log(usage);
    }
}