import { prop, getModelForClass, modelOptions, ReturnModelType, DocumentType, Severity } from "@typegoose/typegoose";
import { ClientMail, ItemList, NewMailScNotify } from "../data/proto/StarRail";
import Session from "../server/kcp/Session";
import Logger from "../util/Logger";

function generateRandomId(uid: number) {
    return Number(`${uid}0${Math.floor(Math.random() * 100000)}`);
}

@modelOptions({ schemaOptions: { collection: "mails" }, options: { customName: "Mail", allowMixed: Severity.ALLOW } })
class Mail {
    @prop({ required: true })
    public toUid!: number;

    @prop({ required: true })
    public title!: string;

    @prop({ required: true })
    public body!: string;

    @prop({ default: { itemList: [{ itemId: 2, num: 300 }] } })
    public attachment!: ItemList;

    @prop({ default: "CrepeSR" })
    public sender!: string;

    @prop({ default: Date.now() / 1000 + 86400 * 7 })
    public expireTime!: number;

    @prop({ default: false })
    public isRead!: boolean;

    @prop({ required: true, unique: true })
    public mailId!: number;

    public parse(this: DocumentType<Mail>, index?: number): ClientMail {
        if (!index) {
            index = this.mailId;
        }

        if (!this.attachment.itemList) this.attachment.itemList = [];
        if (this.attachment.itemList.length === 0) this.attachment.itemList.push({ itemId: 2, num: 300 });

        return {
            attachment: this.attachment,
            content: this.body,
            expireTime: BigInt(Math.round(this.expireTime)),
            id: index,
            isRead: this.isRead,
            sender: this.sender,
            time: BigInt(Math.round(Date.now() / 1000)),
            title: this.title,
        }
    }

    public notify(this: DocumentType<Mail>, session: Session) {
        session.send(NewMailScNotify, {
            "mailIdList": [2503] // Doesn't matter as long as there is an entry (must be unique so it isn't read)
        });
    }

    public static fromUID(this: ReturnModelType<typeof Mail>, uid: number) {
        return this.find({ toUid: uid }).exec();
    }

    public read(this: DocumentType<Mail>) {
        this.isRead = true;
        return this.save();
    }
}

export default getModelForClass(Mail);