import { Banner } from "../util/Banner";

type Bias = 0 | 3 | 4 | 5;

const STANDARD_CHAR_5 = [1003, 1004, 1101, 1104, 1107, 1209, 1211];
const STANDARD_CHAR_4 = [1004, 1005, 1006, 1013, 1101, 1102, 1104, 1203, 1204, 1211];
const STANDARD_LC_5 = [23000, 23001, 23002, 23003, 23004, 23005, 23006, 23007, 23008, 23009, 23010];
const STANDARD_LC_4 = [21000, 21001, 21002, 21003, 21004, 21005, 21006, 21007, 21008, 21009, 21010, 21011, 21012, 21013];
const STANDARD_LC_3 = [20000, 20001, 20002, 20003, 20004, 20005, 20006, 20007, 20008, 20009, 20010, 20011, 20012, 20013];

export default class Gacha {
    private constructor() { }

    public static pull(banner: Banner, bias: Bias = 0): number {
        const STANDARD_5 = [...STANDARD_CHAR_5, ...STANDARD_LC_5];
        const STANDARD_4 = [...STANDARD_CHAR_4, ...STANDARD_LC_4];
        const STANDARD_3 = [...STANDARD_LC_3];

        // Chance of 5* is 0.6%
        // Chance of 4* is 5.1%
        // Chance of 3* is 94.3%
        const roll = Math.random() * 100;
        const isRateUp = !!Math.round(Math.random());
        switch (true) {
            case (roll < 0.6 || bias === 5):
                return isRateUp ? Gacha.random(banner.rateUpItems5) : Gacha.random(STANDARD_5);
            case (roll < 5.1 || bias === 4):
                return isRateUp ? Gacha.random(banner.rateUpItems4) : Gacha.random(STANDARD_4);
            case (roll < 99.4 || bias === 3):
            default:
                return Gacha.random(STANDARD_3);
        }
    }

    private static random(items: number[]): number {
        return items[Math.floor(Math.random() * items.length)];
    }

    public static pullMany(banner: Banner, count: number): number[] {
        const pulls = [];
        for (let i = 0; i < count; i++) {
            const bias = i + 1 === 10 ? 4 : 0;

            pulls.push(this.pull(banner, bias));
        }

        return pulls;
    }
}