import { SceneEntityDisappearScNotify, type SceneEntityInfo, SceneEntityUpdateScNotify } from "../data/proto/StarRail";
import Player from "./Player";
import Logger from "../util/Logger";
import SceneData from "../util/SceneData";
import { ActorEntity } from "./entities/Actor";
import { Entity } from "./entities/Entity";
import { MonsterEntity } from "./entities/Monster";
import { NpcEntity } from "./entities/NPC";
import { PropEntity } from "./entities/Prop";
const c = new Logger("Scene", "cyan");
export class Scene {
    public entryId!: number;
    public entities: Map<number, Entity> = new Map<number, Entity>();
    public plrEntity?: Entity;
    public battleId = 1;

    constructor(public readonly player: Player) {

    }

    public reset() {
        this.entities.clear();
    }

    public spawnEntity(entity: Entity, silent: boolean = false) {
        this.entities.set(entity.entityId, entity);
        if (!silent) {
            const dataObj: SceneEntityUpdateScNotify = {
                entityList: [entity.getSceneEntityInfo()]
            };

            this.player.session.send(SceneEntityUpdateScNotify, dataObj);
        }

        return entity;
    }

    public despawnEntity(entityId: number, silent: boolean = false) {
        this.entities.delete(entityId);
        if (!silent) {
            this.player.session.send(SceneEntityDisappearScNotify, {
                entityIdList: [entityId]
            } as SceneEntityDisappearScNotify);
        }
    }

    public spawnDefaultEntities(): SceneEntityInfo[] {
        const entities = new Array<SceneEntityInfo>();
        for (const e of SceneData.fromId(this.entryId).entities) {
            let entity: Entity;
            switch (true) {
                case "npcMonster" in e:
                    entity = new MonsterEntity(this, e.npcMonster?.monsterId ?? 1002040, e.motion?.pos!, e.motion?.rot);
                    break;
                case "npc" in e:
                    entity = new NpcEntity(this, e.npc?.npcId ?? 1001, e.motion?.pos!, e.motion?.rot);
                    break;
                case "prop" in e:
                    // TODO: Missing proto fields
                    entity = new PropEntity(this, e.prop?.propId ?? 1, e.motion?.pos!, e.motion?.rot);
                    break;
                case "actor" in e:
                    continue;
            }
            
            this.spawnEntity(entity!, true);

            const SEI = entity!.getSceneEntityInfo();
            SEI.groupId = e.groupId;
            SEI.instId = e.instId;
            if (SEI.prop) {
                // TODO: Missing proto fields
                SEI.prop.propState = e.prop?.propState;
            }
            if (SEI.npcMonster) continue; // TODO: Killing SceneCastSkillCsReq is broken
            
            entities.push(SEI);
        }
        
        c.debug(JSON.stringify(entities, null, 4));
        return entities;
    }
}
