import { Request, Response } from "express";
import Logger from "../../../util/Logger";
import { Retcode } from "../../../data/proto/StarRail";
import { Command } from "../../../commands/Interface";
import Config from "../../../util/Config";
import SRServer from "../../../server/kcp/SRServer";
import Whitelist from "../../../util/Whitelist";
const c = new Logger("gm", "green");

export default function handle(req: Request, res: Response) {
    const body = {
        retcode: Retcode.RETCODE_RET_SUCC,
        msg: "OK",
    }

    try {
        if (!Config.GM.VIA_HTTP) {
            body.retcode = Retcode.RETCODE_RET_FAIL;
            body.msg = "GM Commands are disabled";
            return;
        }
        const uid = parseInt(req.query.uid?.toString() || "NaN");
        const command = req.query.command?.toString() || "";
        const password = req.query.password?.toString() || "";
        const cmd = new Command(command);

        if (!Config.GM.WHITELISTED_COMMANDS.includes(cmd.name)) {
            body.retcode = Retcode.RETCODE_RET_FAIL;
            body.msg = "Command not found";
            return;
        }

        if (Config.GM.PASSWORD.length > 0 && password !== Config.GM.PASSWORD) {
            body.retcode = Retcode.RETCODE_RET_IN_GM_BIND_ACCESS;
            body.msg = "Access denied";
            return;
        }

        // Get session from UID
        let session: ReturnType<SRServer["sessions"]["get"]>;
        SRServer.getInstance().sessions.forEach(s => {
            if (s.player?.uid === uid) {
                session = s;
            }
        });

        if (!session) {
            body.retcode = Retcode.RETCODE_RET_FAIL;
            body.msg = "Session not found";
            return;
        }

        if (Config.GM.USE_MAINTENANCE_WHITELIST && !Whitelist.Instance.isWhitelisted(uid)) {
            body.retcode = Retcode.RETCODE_RET_IN_GM_BIND_ACCESS;
            body.msg = "Access denied";
            return;
        }

        import(`../../../commands/${cmd.name}`).then(async module => {
            await module.default(cmd, session);
        }).catch(err => {
            c.error(<Error>err);
            body.retcode = Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR;
            body.msg = "Internal server error (2)";
        });

    } catch (e) {
        c.error(<Error>e);
        body.retcode = Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR;
        body.msg = "Internal server error (3)";
    } finally {
        res.send(body);
    }
}