import { Request, Response } from "express";
import Config from "../../util/Config";
import { Gateserver } from "../../data/proto/StarRail";
import Whitelist from "../../util/Whitelist";

export default function handle(req: Request, res: Response) {
    const UID = parseInt(req.query.uid?.toString() || "NaN");

    const dataObj = Gateserver.fromPartial({
        retcode: 0,
        msg: "OK",
        regionName: "CrepeSR",
        ip: Config.GAMESERVER.SERVER_IP,
        port: Config.GAMESERVER.SERVER_PORT,
        serverDescription: "This is not BingusRail",
        // exResourceUrl: "https://localhost/asb/design",
        // assetBundleUrl: "https://localhost/asb",
        mbRedeemCodeUrl: "http://localhost/common/apicdkey/api",
        loginWhiteMsg: "Access verification failed. Please check if you have logged in to the correct account and server.",
        "assetBundleUrl": "https://autopatchos.starrails.com/asb/V1.0Live/output_4186973_52d0b74c56", //! NEEDED
        "luaUrl": "https://autopatchos.starrails.com/lua/V1.0Live/output_4135247_48f4e37838", //! NEEDED
        "exResourceUrl": "https://autopatchos.starrails.com/design_data/V1.0Live/output_4188516_478ae5483e", //! NEEDED
        // "mbIfixUrl": "https://autopatchos.starrails.com/ifix/V1.0Live/output_4047832_85f647fbbd",
        // Don't download sttuff
        // dataUseAssetBoundle: true, // Either HLANJEOPHMI or FBHCJIFOCMM
        // resUseAssetBoundle: true,  // Either HLANJEOPHMI or FBHCJIFOCMM
        HLANJEOPHMI: true, //! NEEDED
        FBHCJIFOCMM: true, //! NEEDED
        LOOEHGKDCKP: true, //! NEEDED
        // mbResVersion: "4047303", // lua version
        // GJNCMCEHJHB: "4047832", // ifix version
    } as Gateserver);

    if (Config.GAMESERVER.MAINTENANCE && !Whitelist.Instance.isWhitelisted(UID)) {
        dataObj.retcode = 2;
        dataObj.msg = Config.GAMESERVER.MAINTENANCE_MSG;
        dataObj.stopBeginTime = BigInt(Date.now());
        dataObj.stopEndTime = BigInt(Date.now() * 2);
    }

    let rsp;
    try {
        rsp = Gateserver.encode(dataObj).finish();
    } catch {
        rsp = Gateserver.encode(Gateserver.fromPartial({
            retcode: 2,
            msg: "Internal server error",
            stopBeginTime: BigInt(Date.now()),
            stopEndTime: BigInt(Date.now() * 2),
        })).finish();
    }
    res.send(Buffer.from(rsp).toString('base64'));
}