import Logger, { VerboseLevel } from "../../util/Logger";
import protobuf, { Root } from 'protobufjs';
import { resolve } from 'path';
import ProtoFactory from "../../util/ProtoFactory";
import CmdID from "../../data/proto/CmdID";
const c = new Logger("Packet")

export default class Packet {
    public readonly cmdid: number;
    public readonly data: Buffer;
    public body: {} = {};

    public constructor(public readonly rawData: Buffer, public readonly protoName: string = "") {
        // Remove the header and metadata
        const metadataLength = rawData.readUInt16BE(6);
        this.data = rawData.subarray(12 + metadataLength, 12 + metadataLength + rawData.readUInt32BE(8));
        this.cmdid = this.rawData.readUInt16BE(4);

        this.protoName = this.protoName || CmdID[this.cmdid];

        if(this.protoName){
            try {
                const Message = ProtoFactory.getType(this.protoName as PacketName);
                this.body = Message.decode(this.data);
            } catch (e) {
                if (this.data.length === 0) return;
                c.warn(`Failed to decode ${this.protoName}`);
                if (Logger.VERBOSE_LEVEL >= VerboseLevel.ALL) {
                    c.error(e as Error, false);
                }
                c.debug(`Data: ${this.data.toString("hex")}`);
            }
        } else {
            c.error(`Unknown packet id ${this.cmdid}`);
        }
    }

    public static isValid(data: Buffer): boolean {
        // Buffer acting fucky so i'll just use good ol' string manipulation
        const str = data.toString('hex');
        return str.startsWith("9d74c714") && str.endsWith("d7a152c8");
    }


    public static fromEncodedBuffer(data: Buffer, name: PacketName): Buffer {
        const cmdid = CmdID[name];
        const packet = Buffer.allocUnsafe(16 + data.length);
        packet.writeUInt32BE(0x9d74c714);
        packet.writeUint16BE(cmdid, 4);
        packet.writeUint16BE(0, 6);
        packet.writeUint32BE(data.length, 8);
        data.copy(packet, 12);
        packet.writeUint32BE(0xd7a152c8, 12 + data.length);
        return packet;
    }
}

export type PacketName = keyof typeof CmdID;