import { DelMailCsReq, DelMailScRsp, Retcode } from "../../data/proto/StarRail";
import Mail from "../../db/Mail";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    const body = <DelMailCsReq>packet.body;

    if (!body.idList) return session.send(DelMailScRsp, { retcode: Retcode.RETCODE_RET_REQ_PARA_INVALID });

    if (body.idList.length === 0) return session.send(DelMailScRsp, { retcode: Retcode.RETCODE_RET_MAIL_NO_MAIL_TO_DEL });

    for (const id of body.idList) {
        if (id === 1) {
            // System welcome mail - does not actually exist
            continue;
        }

        const mails = await Mail.fromUID(session.player.uid);
        const mail = mails.find(m => m.mailId === id);

        if (!mail) return session.send(DelMailScRsp, { retcode: Retcode.RETCODE_RET_MAIL_NOT_EXIST });

        await mail.deleteOne();
    }

    session.send(DelMailScRsp, { retcode: Retcode.RETCODE_RET_SUCC, idList: body.idList.filter(id => id !== 1) });
}