import { EnterSceneCsReq, EnterSceneScRsp, Retcode } from "../../data/proto/StarRail";
import { ActorEntity } from "../../game/entities/Actor";
import MapEntrance from "../../util/excel/MapEntrance";
import MazePlane from "../../util/excel/MazePlane";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    const body = packet.body as EnterSceneCsReq;

    if (!body.entryId) return session.send(EnterSceneScRsp, { retcode: Retcode.RETCODE_RET_REQ_PARA_INVALID });

    const mazeEntry = MapEntrance.fromId(body.entryId);
    if (!mazeEntry) return session.send(EnterSceneScRsp, { retcode: Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR });
    const mazePlane = MazePlane.fromPlaneId(mazeEntry.PlaneID);
    if (!mazePlane) return session.send(EnterSceneScRsp, { retcode: Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR });

    const posData = session.player.db.posData;
    const entryId = MapEntrance.fromFloorId(posData.floorID)?.ID;
    const _lineup = session.player.db.lineup;
    const lineup = _lineup.lineups[_lineup.curIndex] ?? _lineup.lineups[0];

    session.player.db.posData.floorID = mazeEntry.FloorID;
    session.player.db.posData.planeID = mazeEntry.PlaneID;
    session.player.scene.entryId = body.entryId;
    session.player.save();

    const curAvatarEntity = new ActorEntity(session.player.scene, lineup.avatarList![lineup.leaderSlot!]!, posData.pos);
    session.player.scene.reset();
    session.player.scene.plrEntity = session.player.scene.spawnEntity(curAvatarEntity, true);
    if (entryId) session.player.scene.entryId = entryId;

    session.send(EnterSceneScRsp, {
        retcode: 0,
        // maze: {
        //     floor: {
        //         floorId: mazeEntry.FloorID,
        //         scene: {
        //             planeId: mazeEntry.PlaneID,
        //             floorId: mazeEntry.FloorID,
        //             entryId: body.entryId,
        //             gameModeType: MazePlane.getGameModeForPlaneType(mazePlane.PlaneType),
        //         }
        //     },
        //     id: mazeEntry.PlaneID,
        //     mapEntryId: body.entryId,
        // }
        scene: {
            entryId: body.entryId,
            planeId: mazeEntry.PlaneID,
            gameModeType: MazePlane.getGameModeForPlaneType(mazePlane.PlaneType),
            floorId: mazeEntry.FloorID,
            lightenSectionList: new Array(200).fill(0).map((_, i) => i + 1), // ????
            entityList: [
                curAvatarEntity.getSceneEntityInfo(),
                ...session.player.scene.spawnDefaultEntities(),
            ],
            leaderEntityId: curAvatarEntity.entityId,
        }
    });
}