import { GetCurSceneInfoScRsp, Retcode } from "../../data/proto/StarRail";
import { ActorEntity } from "../../game/entities/Actor";
import MapEntrance from "../../util/excel/MapEntrance";
import MazePlane from "../../util/excel/MazePlane";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    // Get data.
    const posData = session.player.db.posData;
    const _lineup = session.player.db.lineup;
    const lineup = _lineup.lineups[_lineup.curIndex] ?? _lineup.lineups[0];
    const curAvatarEntity = new ActorEntity(session.player.scene, lineup.avatarList![lineup.leaderSlot!]!, posData.pos);
    const entryId = MapEntrance.fromFloorId(posData.floorID)?.ID;
    if (!entryId) return session.send(GetCurSceneInfoScRsp, { retcode: Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR });
    const mazePlane = MazePlane.fromPlaneId(posData.planeID);

    // Scene management.
    session.player.scene.reset();
    session.player.scene.plrEntity = session.player.scene.spawnEntity(curAvatarEntity, true);
    session.player.scene.entryId = entryId;

    // Build response.
    const dataObj: GetCurSceneInfoScRsp = {
        retcode: 0,
        scene: {
            planeId: posData.planeID,
            floorId: posData.floorID,
            entityList: [
                curAvatarEntity.getSceneEntityInfo(),
                ...session.player.scene.spawnDefaultEntities(),
            ],
            lightenSectionList: new Array(200).fill(0).map((_, i) => i + 1),
            leaderEntityId: curAvatarEntity.entityId, // leaderEntityId
            entityBuffList: [],
            entryId: entryId,
            envBuffList: [],
            gameModeType: MazePlane.getGameModeForPlaneType(mazePlane?.PlaneType ?? "Maze"), // Statistically "Maze" is the most common plane type
        }
    };

    // Send response.
    session.send(GetCurSceneInfoScRsp, dataObj);
}