import { GetShopListScRsp, GetShopListCsReq, Shop, Goods } from "../../data/proto/StarRail";
import ShopConfig from "../../util/excel/ShopConfig";
import ShopGoodsConfig from "../../util/excel/ShopGoodsConfig";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    const body = packet.body as GetShopListCsReq;

    if (!body.shopType) return session.send(GetShopListScRsp, <any>defaultObj);

    const dataObj = {
        retcode: 0,
        shopType: body.shopType,
        shopList: []
    } as GetShopListScRsp;

    const shops = ShopConfig.fromType(body.shopType);

    for (const shop of shops) {
        const goods = ShopGoodsConfig.fromShopId(shop.ShopID);
        const shopObj: Shop = {
            shopId: shop.ShopID,
            beginTime: BigInt(Math.floor(Date.now() / 1000)),
            endTime: BigInt(Math.floor(Date.now() / 1000) + 3600),
            goodsList: [],
            cityLevel: 1,
        };

        for (const good of goods) {
            shopObj.goodsList!.push({
                beginTime: BigInt(Math.floor(Date.now() / 1000)),
                endTime: BigInt(Math.floor(Date.now() / 1000) + 3600),
                goodsId: good.GoodsID,
                itemId: good.ItemID,
            });
        }

        dataObj.shopList!.push(shopObj);
    }

    session.send(GetShopListScRsp, dataObj);
}

const defaultObj = {
    "shopList": [
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 101001,
                    "itemId": 101,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 101002,
                    "itemId": 102,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 6
                },
                {
                    "goodsId": 101003,
                    "itemId": 1009,
                    "beginTime": 1659430800,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 101004,
                    "itemId": 1008,
                    "beginTime": 1659430800,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 101012,
                    "itemId": 23000,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 101013,
                    "itemId": 23002,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 101014,
                    "itemId": 23003,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 101015,
                    "itemId": 23004,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 101016,
                    "itemId": 23005,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 101017,
                    "itemId": 23012,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 101018,
                    "itemId": 23013,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                }
            ],
            "shopId": 101,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 102001,
                    "itemId": 102,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 5
                },
                {
                    "goodsId": 102002,
                    "itemId": 101,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 5
                },
                {
                    "goodsId": 102003,
                    "itemId": 241,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102004,
                    "itemId": 212,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 80
                },
                {
                    "goodsId": 102005,
                    "itemId": 222,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102006,
                    "itemId": 2,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102007,
                    "itemId": 110111,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102008,
                    "itemId": 110121,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 20
                },
                {
                    "goodsId": 102009,
                    "itemId": 110131,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102010,
                    "itemId": 110141,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102011,
                    "itemId": 110151,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102012,
                    "itemId": 110161,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102013,
                    "itemId": 110171,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 10
                },
                {
                    "goodsId": 102014,
                    "itemId": 111001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102015,
                    "itemId": 111011,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102016,
                    "itemId": 112001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102017,
                    "itemId": 112011,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102018,
                    "itemId": 113001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102019,
                    "itemId": 113011,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 102099,
                    "itemId": 2,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                }
            ],
            "shopId": 102,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 202001,
                    "itemId": 21003,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 202002,
                    "itemId": 21027,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 202003,
                    "itemId": 21002,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 202004,
                    "itemId": 21007,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 202005,
                    "itemId": 21026,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 202006,
                    "itemId": 21008,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 202007,
                    "itemId": 21004,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                }
            ],
            "shopId": 202,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 301001,
                    "itemId": 190122,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 301002,
                    "itemId": 190123,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 301003,
                    "itemId": 300200,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                }
            ],
            "shopId": 301,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 302001,
                    "itemId": 190121,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 302002,
                    "itemId": 190125,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 302004,
                    "itemId": 190136,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 302005,
                    "itemId": 190137,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                }
            ],
            "shopId": 302,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 303001,
                    "itemId": 400004,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 303002,
                    "itemId": 400006,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 303003,
                    "itemId": 400007,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 303004,
                    "itemId": 401003,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 303005,
                    "itemId": 401008,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 303006,
                    "itemId": 401006,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 303007,
                    "itemId": 402001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 10
                },
                {
                    "goodsId": 303008,
                    "itemId": 402002,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 5
                },
                {
                    "goodsId": 303009,
                    "itemId": 408004,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 5
                },
                {
                    "goodsId": 304013,
                    "itemId": 405011,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                }
            ],
            "shopId": 303,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 304001,
                    "itemId": 180001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 304002,
                    "itemId": 180002,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 304003,
                    "itemId": 180007,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 304004,
                    "itemId": 180006,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 304005,
                    "itemId": 181002,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 304006,
                    "itemId": 181005,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 304007,
                    "itemId": 181006,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 304008,
                    "itemId": 181007,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 304009,
                    "itemId": 182004,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 304010,
                    "itemId": 210100,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 304011,
                    "itemId": 406012,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 304012,
                    "itemId": 406009,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                }
            ],
            "shopId": 304,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 305001,
                    "itemId": 180001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 305002,
                    "itemId": 180002,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 305003,
                    "itemId": 180004,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 305004,
                    "itemId": 180005,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 305005,
                    "itemId": 181001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 305006,
                    "itemId": 181003,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 305007,
                    "itemId": 181004,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 305008,
                    "itemId": 181008,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 305009,
                    "itemId": 182007,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 10
                },
                {
                    "goodsId": 305010,
                    "itemId": 210112,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 305011,
                    "itemId": 406011,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 305012,
                    "itemId": 406014,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 305013,
                    "itemId": 140165,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                }
            ],
            "shopId": 305,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 306001,
                    "itemId": 180001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 306002,
                    "itemId": 180002,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 306003,
                    "itemId": 180006,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 306004,
                    "itemId": 181010,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 306005,
                    "itemId": 181009,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 306006,
                    "itemId": 182003,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 306007,
                    "itemId": 406010,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 306008,
                    "itemId": 406013,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 306009,
                    "itemId": 406015,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                }
            ],
            "shopId": 306,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 9,
            "cityExp": 70,
            "goodsList": [
                {
                    "goodsId": 401001,
                    "itemId": 212,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 25
                },
                {
                    "goodsId": 401002,
                    "itemId": 222,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 15
                },
                {
                    "goodsId": 401003,
                    "itemId": 41021,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 401004,
                    "itemId": 41022,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 401005,
                    "itemId": 41023,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 401006,
                    "itemId": 41024,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 401007,
                    "itemId": 111001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 20
                },
                {
                    "goodsId": 401008,
                    "itemId": 111011,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 20
                },
                {
                    "goodsId": 401009,
                    "itemId": 110111,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 5
                },
                {
                    "goodsId": 401010,
                    "itemId": 110121,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 5
                },
                {
                    "goodsId": 401011,
                    "itemId": 110131,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 5
                },
                {
                    "goodsId": 401012,
                    "itemId": 110141,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 4
                },
                {
                    "goodsId": 401013,
                    "itemId": 110151,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 401014,
                    "itemId": 110161,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 401015,
                    "itemId": 110171,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 401016,
                    "itemId": 2,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 401017,
                    "itemId": 407005,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                }
            ],
            "shopId": 401,
            "cityTakenLevelReward": 1020,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 13,
            "cityExp": 160,
            "goodsList": [
                {
                    "goodsId": 402001,
                    "itemId": 212,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 50
                },
                {
                    "goodsId": 402002,
                    "itemId": 222,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 20
                },
                {
                    "goodsId": 402003,
                    "itemId": 232,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 20
                },
                {
                    "goodsId": 402004,
                    "itemId": 51031,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 402005,
                    "itemId": 51032,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 402006,
                    "itemId": 51033,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 402007,
                    "itemId": 51034,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 402008,
                    "itemId": 112001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 20
                },
                {
                    "goodsId": 402009,
                    "itemId": 112011,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 20
                },
                {
                    "goodsId": 402010,
                    "itemId": 110111,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 10
                },
                {
                    "goodsId": 402011,
                    "itemId": 110121,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 402012,
                    "itemId": 110131,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 402013,
                    "itemId": 110141,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 10
                },
                {
                    "goodsId": 402014,
                    "itemId": 110151,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 402015,
                    "itemId": 110161,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 402016,
                    "itemId": 110171,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 402018,
                    "itemId": 2,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 402019,
                    "itemId": 407004,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 402020,
                    "itemId": 406004,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                }
            ],
            "shopId": 402,
            "cityTakenLevelReward": 16380,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 5,
            "cityExp": 14,
            "goodsList": [
                {
                    "goodsId": 403001,
                    "itemId": 212,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 9
                },
                {
                    "goodsId": 403002,
                    "itemId": 222,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 403003,
                    "itemId": 232,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 20
                },
                {
                    "goodsId": 403004,
                    "itemId": 51021,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403005,
                    "itemId": 51022,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403006,
                    "itemId": 51023,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403007,
                    "itemId": 51024,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403008,
                    "itemId": 113001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403009,
                    "itemId": 113011,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403010,
                    "itemId": 110111,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403011,
                    "itemId": 110121,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403012,
                    "itemId": 110131,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403013,
                    "itemId": 110141,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403014,
                    "itemId": 110151,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403015,
                    "itemId": 110161,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403016,
                    "itemId": 110171,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403017,
                    "itemId": 2,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 403018,
                    "itemId": 407006,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                }
            ],
            "shopId": 403,
            "cityTakenLevelReward": 60,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 501001,
                    "itemId": 24000,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 501002,
                    "itemId": 24001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 501003,
                    "itemId": 24002,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 501004,
                    "itemId": 271,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 501005,
                    "itemId": 101,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                }
            ],
            "shopId": 501,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 900001,
                    "itemId": 310001,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 900002,
                    "itemId": 310002,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 900003,
                    "itemId": 310003,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                }
            ],
            "shopId": 900,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 999001,
                    "itemId": 101,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                },
                {
                    "goodsId": 999002,
                    "itemId": 102,
                    "beginTime": 1622192400,
                    "endTime": 1893315600
                }
            ],
            "shopId": 999,
            "beginTime": 1622192400
        },
        {
            "endTime": 1893315600,
            "cityLevel": 1,
            "goodsList": [
                {
                    "goodsId": 1000001,
                    "itemId": 101,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 1
                },
                {
                    "goodsId": 1000002,
                    "itemId": 102,
                    "beginTime": 1622192400,
                    "endTime": 1893315600,
                    "buyTimes": 63
                }
            ],
            "shopId": 1000,
            "beginTime": 1622192400
        }
    ]
}