import { MarkReadMailScRsp, Retcode } from "../../data/proto/StarRail";
import Mail from "../../db/Mail";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    const id = parseInt((<any>packet.body).id);

    if (isNaN(id)) return session.send(MarkReadMailScRsp, { retcode: Retcode.RETCODE_RET_MAIL_MAIL_ID_INVALID });

    if (id === 0) {
        // System welcome mail - does not actually exist
        return session.send(MarkReadMailScRsp, { retcode: Retcode.RETCODE_RET_SUCC });
    }

    const mails = await Mail.fromUID(session.player.uid);
    const mail = mails.find(m => m.mailId === id);

    if (!mail) return session.send(MarkReadMailScRsp, { retcode: Retcode.RETCODE_RET_MAIL_MAIL_ID_INVALID });

    mail.isRead = true;
    await mail.save();

    session.send(MarkReadMailScRsp, { retcode: Retcode.RETCODE_RET_SUCC });
}