import { PromoteAvatarCsReq, PromoteAvatarScRsp, Retcode } from "../../data/proto/StarRail";
import Avatar from "../../db/Avatar";
import { PayItemData } from "../../db/Inventory";
import AvatarPromotionConfig from "../../util/excel/AvatarPromotionConfig";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    const body = packet.body as PromoteAvatarCsReq;
    const inventory = await session.player.getInventory();

    // Get the target avatar.
    const avatarId = body.baseAvatarId;

    if (!avatarId) {
        return session.send(PromoteAvatarScRsp, { retcode: Retcode.RETCODE_RET_AVATAR_NOT_EXIST });
    }

    const avatar = await Avatar.getAvatar(session.player, avatarId);
    const promotionExcelData = AvatarPromotionConfig.fromId(avatarId, avatar.promotion);

    if (!promotionExcelData) {
        return session.send(PromoteAvatarScRsp, { retcode: Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR });
    }

    // Build list of consumed items. We take this from the excel, instead of the Req.
    const costMaterialList = promotionExcelData.PromotionCostList.map(c => { return { id: c.ItemID, count: c.ItemNum } as PayItemData });

    // Try consuming materials.
    const success = await inventory.payItems(costMaterialList, session.player);
    if (!success) {
        // ToDo: Correct retcode.
        session.send(PromoteAvatarScRsp, { retcode: Retcode.RETCODE_RET_ITEM_NOT_ENOUGH });
        return;
    }

    await inventory.save();

    // Promote the avatar and save.
    avatar.promotion++;
    await avatar.save();

    // Done. Sync and send response.
    await session.sync();
    session.send(PromoteAvatarScRsp, { retcode: Retcode.RETCODE_RET_SUCC });
}