import { RankUpAvatarCsReq, RankUpAvatarScRsp, Retcode } from "../../data/proto/StarRail";
import Avatar from "../../db/Avatar";
import { PayItemData } from "../../db/Inventory";
import Logger from "../../util/Logger";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";
const c = new Logger("RankUpAvatarCsReq");

export default async function handle(session: Session, packet: Packet) {
    const body = packet.body as RankUpAvatarCsReq;
    const dataObj: RankUpAvatarScRsp = {
        retcode: 0
    };

    try {
        const inv = await session.player.getInventory();
        if (!body.costData) return;
        const list = body.costData.itemList;

        if (!list) {
            return session.send(RankUpAvatarScRsp, { retcode: Retcode.RETCODE_RET_REQ_PARA_INVALID });
        }

        const arr: Array<PayItemData> = [];

        for (let i = 0; i < list.length; i++) {
            const item = list[i];
            if (!item.pileItem) continue;
            arr.push({
                count: item.pileItem.itemNum!,
                id: item.pileItem.itemId!
            });
        }

        if (await inv.payItems(arr)) {
            const avatar = await Avatar.getAvatar(session.player, body.baseAvatarId ?? 0);

            if (!avatar || !body.rank) {
                dataObj.retcode = Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR;
                return;
            }

            avatar.rank = body.rank // gidra moment: ez hack
            await avatar.save();
        } else {
            dataObj.retcode = 1301;
        }
    } catch (e) {
        c.error(e as Error);
        dataObj.retcode = 2;
    } finally {
        session.send(RankUpAvatarScRsp, dataObj);
        session.sync();
    }
}