import { RankUpEquipmentCsReq, RankUpEquipmentScRsp, Retcode } from "../../data/proto/StarRail";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    const body = packet.body as RankUpEquipmentCsReq;
    const inventory = await session.player.getInventory();

    if (!body.equipmentUniqueId || !body.costData?.itemList)
        return session.send(RankUpEquipmentScRsp, { retcode: Retcode.RETCODE_RET_REQ_PARA_INVALID } as RankUpEquipmentScRsp);

    // Get equipment.
    const equipment = inventory.getEquipment(body.equipmentUniqueId);

    // Check if all sacrificed equipments exist.
    if (!equipment) {
        return session.send(RankUpEquipmentScRsp, { retcode: Retcode.RETCODE_RET_EQUIPMENT_NOT_EXIST } as RankUpEquipmentScRsp);
    }

    // Remove sacrificed equipments.
    for (const equip of body.costData.itemList) {
        const item = inventory.getEquipment(equip.equipmentUniqueId || -1);
        if (!item) {
            return session.send(RankUpEquipmentScRsp, { retcode: Retcode.RETCODE_RET_EQUIPMENT_NOT_EXIST } as RankUpEquipmentScRsp);
        }

        await inventory.removeEquipment(equip.equipmentUniqueId!);
    }

    // Increase rank and save.
    equipment!.rank && equipment!.rank++;
    await inventory.save();

    // Done. Send and sync.
    await session.sync();
    session.send(RankUpEquipmentScRsp, { retcode: 0 } as RankUpEquipmentScRsp);
}