import { AvatarType, ScenePlaneEventScNotify, SceneCastSkillCsReq, SceneCastSkillScRsp, SceneMonsterWave } from "../../data/proto/StarRail";
import Avatar from "../../db/Avatar";
import { MonsterEntity } from "../../game/entities/Monster";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

// Example body:
// {
//     hitTargetEntityIdList: [2097214],
//     skillIndex: 0,
//     targetMotion: { rot: { x: 0, y: 0, z: 0 }, pos: { x: 0, y: 294, z: 216720 } },
//     assistMonsterEntityIdList: [],
//     abilityTargetEntityId: 2097214,
//     castEntityId: 0
// }

export default async function handle(session: Session, packet: Packet) {
    const body = <SceneCastSkillCsReq>packet.body;

    // Don't break the players game for now
    if (body.hitTargetEntityIdList?.length == 0) return session.send(SceneCastSkillScRsp, {
        retcode: 0,
    });

    session.send(ScenePlaneEventScNotify, {
        reward: { itemList: [{ itemId: 1, num: 1 }] }
    });

    if (body.hitTargetEntityIdList && body.hitTargetEntityIdList.length > 0) {
        const player = session.player;
        const inventory = await player.getInventory();
        const avatars = await Avatar.getAvatarsForLineup(player, player.db.lineup.lineups[player.db.lineup.curIndex]);
        const enemies = body.hitTargetEntityIdList.map(x => session.player.scene.entities.get(x)) as MonsterEntity[];
        if (enemies.length == 0) return;

        session.send(SceneCastSkillScRsp, {
            retcode: 0,
            battleInfo: {
                logicRandomSeed: 1,
                mechanismBarInfo: {},
                stageId: 1022010, // TODO eventId
                monsterWaveList: [
                    {
                        monsterParam: {},
                        dropList: [{ itemList: [{ itemId: 102, num: 10 }] }],
                        monsterList: [enemies.map(x => { return { monsterId: x.monsterId } })],
                    } as SceneMonsterWave
                ],
                battleAvatarList: avatars.map((avatar, i) => {
                    const equipment = inventory.equipments.find(x => x.uniqueId == avatar.equipmentUniqueId);
                    const equipData = (equipment) ? [{
                        id: equipment.tid,
                        level: equipment.level,
                        promotion: equipment.promotion,
                        rank: equipment.rank
                    }] : [];

                    return {
                        avatarType: avatar.avatarType,
                        equipmentList: equipData,
                        hp: avatar.fightProps.hp,
                        id: avatar.baseAvatarId,
                        sp: avatar.fightProps.sp,
                        index: i,
                        level: avatar.level,
                        promotion: avatar.promotion,
                        rank: avatar.rank,
                        relicList: [],
                        skilltreeList: []
                    };
                }),
                buffList: [],
                battleId: session.player.scene.battleId++, // Increasing
                // heroPathList: [],
                // roundsLimit: 100
            }
        });
    }
}