import { BattleBuff, HeroPath, Item, ItemList, SceneEnterStageCsReq, SceneEnterStageScRsp, SceneMonsterWave } from "../../data/proto/StarRail";
import Avatar from "../../db/Avatar";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    const body = <SceneEnterStageCsReq>packet.body;

    const player = session.player;
    const inventory = await player.getInventory();
    const avatars = await Avatar.getAvatarsForLineup(player, player.db.lineup.lineups[player.db.lineup.curIndex]);
    const monsters = [101202001];

    const dataObj = <SceneEnterStageScRsp>{
        retcode: 0,
        battleInfo: {
            logicRandomSeed: 1,
            stageId: body.stageId,
            monsterWaveList: [
                {
                    monsterIdList: monsters,
                    dropList: [{ itemList: [{ itemId: 102, num: 10 } as Item] } as ItemList],
                    monsterList: []
                } as SceneMonsterWave
            ],
            battleAvatarList: avatars.map((avatar, i) => {
                const equipment = inventory.getEquipment(avatar.equipmentUniqueId ?? 0);
                const equipData = (equipment) ? [{
                    id: equipment.tid,
                    level: equipment.level,
                    promotion: equipment.promotion,
                    rank: equipment.rank
                }] : [];

                return {
                    avatarType: avatar.avatarType,
                    equipmentList: equipData,
                    hp: avatar.fightProps.hp,
                    id: avatar.baseAvatarId,
                    sp: avatar.fightProps.sp,
                    index: i,
                    level: avatar.level,
                    promotion: avatar.promotion,
                    rank: avatar.rank,
                    relicList: [],
                    skilltreeList: []
                };
            }),
            buffList: new Array<BattleBuff>(),
            battleId: body.eventId,
            heroPathList: new Array<HeroPath>(),
            roundsLimit: 100
        }
    }

    for (const monster of monsters) {
        dataObj.battleInfo!.monsterWaveList![0].monsterList!.push({
            curHp: 5000,
            maxHp: 5000,
            monsterId: monster,
        });
    }

    session.send(SceneEnterStageScRsp, dataObj);
}