import { Retcode, SetSignatureCsReq, SetSignatureScRsp } from "../../data/proto/StarRail";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";
import { Command } from "../../commands/Interface"
import Config from "../../util/Config";
import Logger from "../../util/Logger";

export default async function handle(session: Session, packet: Packet) {
    const body = packet.body as SetSignatureCsReq;

    if (Config.GM.VIA_SIGN_REQ) {
        const command = body.signature!;
        if (Logger.VERBOSE_LEVEL >= 1) session.c.trail(command);

        const cmd = new Command(command);
        const dataObj: SetSignatureScRsp = {};

        if (!Config.GM.WHITELISTED_COMMANDS.includes(cmd.name)) {
            dataObj.retcode = Retcode.RETCODE_RET_SIGNATURE_SENSITIVE_WORDS;
            return session.send(SetSignatureScRsp, dataObj);
        }

        import(`../../commands/${cmd.name}`).then(async module => {
            await module.default(cmd, session);
        }).catch(err => {
            dataObj.retcode = Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR;
        });

        session.send(SetSignatureScRsp, dataObj);
    } else {
        session.send(SetSignatureScRsp, { retcode: Retcode.RETCODE_RET_SUCC });
    }
}
