import { Retcode, StartCocoonStageCsReq, StartCocoonStageScRsp } from "../../data/proto/StarRail";
import Avatar from "../../db/Avatar";
import CocoonConfig from "../../util/excel/CocoonConfig";
import StageConfig from "../../util/excel/StageConfig";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

// req: { wave: 0, cocoonId: 1001, worldLevel: 0, propEntityId: 0 }
export default async function handle(session: Session, packet: Packet) {
    const body = <StartCocoonStageCsReq>packet.body;

    if (!body.cocoonId) return session.send(StartCocoonStageScRsp, { retcode: Retcode.RETCODE_RET_REQ_PARA_INVALID });

    const cocoon = true ? CocoonConfig.random() : CocoonConfig.fromId(body.cocoonId!, body.worldLevel || session.player.db.basicInfo.worldLevel);
    if (!cocoon) return session.send(StartCocoonStageScRsp, { retcode: Retcode.RETCODE_RET_STAGE_COCOON_NOT_OPEN });

    const stage = StageConfig.fromId(cocoon.StageID ?? 1022010);
    if (!stage) return session.send(StartCocoonStageScRsp, { retcode: Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR });
    const waves = StageConfig.parse(stage);

    const inventory = await session.player.getInventory();
    const avatars = await Avatar.getAvatarsForLineup(session.player, session.player.db.lineup.lineups[session.player.db.lineup.curIndex]);

    const dataObj = <StartCocoonStageScRsp>{
        retcode: Retcode.RETCODE_RET_SUCC,
        propEntityId: body.propEntityId,
        cocoonId: body.cocoonId,
        wave: body.wave,
        battleInfo: {
            mapId: 1022030,
            logicRandomSeed: Math.round(Math.random() * 1000000000), // Don't hardcode here, in case the fights get repeating and boring
            stageId: cocoon.StageID ?? 1022011,
            battleAvatarList: avatars.map((avatar, i) => {
                const equipment = inventory.getEquipment(avatar.equipmentUniqueId ?? 0);
                const equipData = (equipment) ? [{
                    id: equipment.tid,
                    level: equipment.level,
                    promotion: equipment.promotion,
                    rank: equipment.rank
                }] : [];

                return {
                    avatarType: avatar.avatarType,
                    equipmentList: equipData,
                    hp: avatar.fightProps.hp,
                    id: avatar.baseAvatarId,
                    sp: avatar.fightProps.sp,
                    index: i,
                    level: avatar.level,
                    promotion: avatar.promotion,
                    rank: avatar.rank,
                    relicList: [],
                    skilltreeList: []
                };
            }),
            battleId: session.player.scene.battleId++,
            monsterWaveList: [],
            Unk09057DIDDMMAKIMJList: [
                {
                    "id": 20002,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20003,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20004,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20005,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20006,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20008,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20009,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20010,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20011,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20012,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20013,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20015,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20016,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20017,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20019,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20020,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20021,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20022,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20024,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20026,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20027,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20029,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20030,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20031,
                    "BPGMAKCBGCJ": 20
                },
                {
                    "id": 20032,
                    "BPGMAKCBGCJ": 60
                },
                {
                    "id": 20033,
                    "OFMPOGJCHDH": 1,
                    "BPGMAKCBGCJ": 20
                },
                {
                    "id": 20034,
                    "OFMPOGJCHDH": 1,
                    "BPGMAKCBGCJ": 60
                },
                {
                    "id": 20035,
                    "OFMPOGJCHDH": 4,
                    "BPGMAKCBGCJ": 20
                },
                {
                    "id": 20036,
                    "OFMPOGJCHDH": 4,
                    "BPGMAKCBGCJ": 60
                },
                {
                    "id": 20037,
                    "OFMPOGJCHDH": 11,
                    "BPGMAKCBGCJ": 20
                },
                {
                    "id": 20038,
                    "OFMPOGJCHDH": 11,
                    "BPGMAKCBGCJ": 60
                },
                {
                    "id": 20039,
                    "BPGMAKCBGCJ": 100
                },
                {
                    "id": 20040,
                    "BPGMAKCBGCJ": 300
                },
                {
                    "id": 20041,
                    "OFMPOGJCHDH": 33,
                    "BPGMAKCBGCJ": 100
                },
                {
                    "id": 20042,
                    "OFMPOGJCHDH": 33,
                    "BPGMAKCBGCJ": 300
                },
                {
                    "id": 20043,
                    "BPGMAKCBGCJ": 100
                },
                {
                    "id": 20044,
                    "BPGMAKCBGCJ": 300
                },
                {
                    "id": 20045,
                    "OFMPOGJCHDH": 6,
                    "BPGMAKCBGCJ": 80
                },
                {
                    "id": 20046,
                    "OFMPOGJCHDH": 6,
                    "BPGMAKCBGCJ": 240
                },
                {
                    "id": 20047,
                    "BPGMAKCBGCJ": 10
                },
                {
                    "id": 20048,
                    "OFMPOGJCHDH": 5,
                    "BPGMAKCBGCJ": 80
                },
                {
                    "id": 20049,
                    "OFMPOGJCHDH": 5,
                    "BPGMAKCBGCJ": 240
                },
                {
                    "id": 20050,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20052,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20054,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20056,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20057,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20058,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20059,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20060,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20063,
                    "BPGMAKCBGCJ": 20
                },
                {
                    "id": 20064,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20066,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20067,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20068,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 20069,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30001,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30002,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30004,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30005,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30006,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30008,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30010,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30011,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30012,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30016,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30017,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30020,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30021,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30024,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30034,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30037,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30038,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30039,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30040,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30041,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30042,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30043,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30044,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30045,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 30046,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 40003,
                    "BPGMAKCBGCJ": 1
                },
                {
                    "id": 40011,
                    "BPGMAKCBGCJ": 1
                }
            ]
        }
    };

    for (const wave of waves) {
        dataObj.battleInfo?.monsterWaveList?.push({
            monsterList: wave.map(x => {
                return {
                    monsterId: x
                }
            }),
            dropList: Array(wave.length).fill({ itemList: [{ itemId: 102, num: 10 }] }), // TODO
            monsterParam: {}
        });
    }

    session.send(StartCocoonStageScRsp, dataObj);
}