import { Retcode, SwapLineupCsReq, SwapLineupScRsp, SyncLineupNotify, SyncLineupReason } from "../../data/proto/StarRail";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    const body = packet.body as SwapLineupCsReq;

    let lineup = await session.player.getLineup();

    if (!body.dstSlot || !body.srcSlot) {
        session.send(SwapLineupScRsp, { retcode: Retcode.RETCODE_RET_LINEUP_SWAP_NOT_EXIST } as SwapLineupScRsp);
        return;
    }

    if (!lineup || !lineup.avatarList) {
        session.send(SwapLineupScRsp, { retcode: Retcode.RETCODE_RET_LINEUP_SWAP_NOT_EXIST } as SwapLineupScRsp);
        return;
    };

    const _copy = lineup.avatarList[body.dstSlot];
    lineup.avatarList[body.dstSlot] = lineup.avatarList[body.srcSlot];
    lineup.avatarList[body.srcSlot] = _copy;

    session.player.setLineup(lineup);
    session.player.save();

    session.send(SwapLineupScRsp, { retcode: 0 });
    session.send(SyncLineupNotify, {
        lineup: lineup,
        reasonList: [SyncLineupReason.SYNC_LINEUP_REASON_SYNC_REASON_NONE]
    } as SyncLineupNotify);
}