import { BpRewardType, Retcode, TakeBpRewardCsReq, TakeBpRewardScRsp } from "../../data/proto/StarRail";
import BattlePassLevel from "../../util/excel/BattlePassLevel";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

// Body example: { optionalRewardId: 0, level: 23, type: 2 }
export default async function handle(session: Session, packet: Packet) {
    const body = packet.body as TakeBpRewardCsReq;

    if (!body.level || !body.type) return session.send(TakeBpRewardScRsp, { retcode: Retcode.RETCODE_RET_REQ_PARA_INVALID });

    const levelReward = BattlePassLevel.fromLevel(1, body.level);

    if (!levelReward) return session.send(TakeBpRewardScRsp, { retcode: Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR });

    const dataObj = <TakeBpRewardScRsp>{
        retcode: Retcode.RETCODE_RET_SUCC,
        reward: { itemList: [] }
    };

    let itemId: number = 0;
    switch (body.type) {
        case BpRewardType.BP_REWARD_TYPE_BP_REWARAD_TYPE_FREE:
            itemId = levelReward.FreeReward;
            break;
        case BpRewardType.BP_REWARD_TYPE_BP_REWARAD_TYPE_PREMIUM1:
            itemId = levelReward.PremiumFixedReward1;
            break;
        case BpRewardType.BP_REWARD_TYPE_BP_REWARAD_TYPE_PREMIUM2:
            itemId = levelReward.PremiumFixedReward2 ?? 1;
            break;
        case BpRewardType.BP_REWARD_TYPE_BP_REWARAD_TYPE_PREMIUM_OPTIONAL:
            if (!body.optionalRewardId) return session.send(TakeBpRewardScRsp, { retcode: Retcode.RETCODE_RET_REQ_PARA_INVALID });
            itemId = body.optionalRewardId;
            break;
        default:
            return session.send(TakeBpRewardScRsp, { retcode: Retcode.RETCODE_RET_REQ_PARA_INVALID });
    }
    dataObj.reward!.itemList!.push({ itemId: itemId, num: 1 });

    const inv = await session.player.getInventory();
    await inv.addItem(itemId, 1);

    session.send(TakeBpRewardScRsp, dataObj);
}