import { TakeMailAttachmentCsReq, TakeMailAttachmentScRsp, Retcode, ClientMailAttachmentItem, ItemList } from "../../data/proto/StarRail";
import Mail from "../../db/Mail";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    const body = <TakeMailAttachmentCsReq>packet.body;

    if (!body.mailIdList || body.mailIdList.length === 0) return session.send(TakeMailAttachmentScRsp, { retcode: Retcode.RETCODE_RET_REQ_PARA_INVALID });

    const inv = await session.player.getInventory();
    const mails = await Mail.fromUID(session.player.uid);
    const succMailIdList = new Array<number>();
    const failMailList = new Array<ClientMailAttachmentItem>();
    const attachment: ItemList = { itemList: [] };
    let retcode = Retcode.RETCODE_RET_SERVER_INTERNAL_ERROR;
    for (const mailId of body.mailIdList) {
        if (mailId === 1) {
            // Dummy mail, but allow anyway
            succMailIdList.push(mailId);
            attachment.itemList!.push({ itemId: 1102, num: 1, level: 80 });
            retcode = Retcode.RETCODE_RET_SUCC;
            continue;
        }

        const mail = mails.find(m => m.mailId === mailId);

        if (!mail) {
            failMailList.push({ mailId });
            retcode = Retcode.RETCODE_RET_MAIL_NOT_EXIST;
            continue;
        }

        if (!mail.attachment?.itemList || mail.attachment.itemList.length === 0) {
            failMailList.push({ mailId });
            retcode = Retcode.RETCODE_RET_MAIL_NO_MAIL_TAKE_ATTACHMENT;
            continue;
        }

        // Take mail reward
        for (const item of mail.attachment.itemList) {
            inv.addItem(item.itemId!, item.num!, session.player);
        }

        // Read mail
        mail.isRead = true;
        await mail.save();
        await session.player.save();
        succMailIdList.push(mailId);
        attachment.itemList!.push(...mail.attachment.itemList);
        retcode = Retcode.RETCODE_RET_SUCC;
    }

    await inv.save();
    await session.sync();
    session.send(TakeMailAttachmentScRsp, { retcode, succMailIdList, failMailList, attachment });
}