import { Retcode, TakeQuestRewardCsReq, TakeQuestRewardScRsp } from "../../data/proto/StarRail";
import RewardData from "../../util/excel/RewardData";
import Packet from "../kcp/Packet";
import Session from "../kcp/Session";

export default async function handle(session: Session, packet: Packet) {
    const body = <TakeQuestRewardCsReq>packet.body;

    if (!body.questIdList || body.questIdList.length === 0) return session.send(TakeQuestRewardScRsp, { retcode: Retcode.RETCODE_RET_REQ_PARA_INVALID });

    const inv = await session.player.getInventory();
    const succQuestIdList: number[] = [];
    const itemList = [];
    for (const questId of body.questIdList) {
        const _reward = RewardData.fromId(questId);
        const reward = RewardData.parse(_reward);
        if (!reward) continue;

        for (const item of reward.itemList) {
            await inv.addItem(item.itemId!, item.num!);
            itemList.push(item);
        }

        succQuestIdList.push(questId);
    }

    session.send(TakeQuestRewardScRsp, { retcode: Retcode.RETCODE_RET_SUCC, succQuestIdList, reward: { itemList } });
}