import acfg from "acfg";

export default acfg({
    // General
    VERBOSE_LEVEL: 1,

    // MongoDB
    MONGO_URI: "mongodb://0.0.0.0:27017/crepesr",

    // HTTP
    HTTP: {
        HTTP_HOST: "0.0.0.0",
        HTTP_PORT: 80,
        HTTPS_PORT: 443
    },

    // Dispatch
    DISPATCH: [{
        DISPATCH_NAME: "CrepeSR",
        DISPATCH_URL: "http://localhost/query_gateway"
    }],

    // GameServer
    GAMESERVER: {
        SERVER_IP: "127.0.0.1",
        SERVER_PORT: 22102,
        MAINTENANCE: false,
        MAINTENANCE_MSG: "Server is in maintenance mode.",
    },

    // Commands via signature or HTTP API
    //? Signature doesn't require password at all
    //? HTTP API requires password
    //? Both follow command and user whitelist
    GM: {
        VIA_HTTP: true, // /api/gm
        VIA_SIGN_REQ: true, // SetSignatureCsReq
        PASSWORD: generateRandomString(16), // Leave empty to disable password
        WHITELISTED_COMMANDS: ["avatar", "battle", "item", "scene", "sync", "worldlevel", "wl", "mail", "packet", "level"],
        USE_MAINTENANCE_WHITELIST: false, // If false, everyone can use them
    },
    AUTO_ACCOUNT: false
}, { logMissing: true });

function generateRandomString(length: number) {
    const chars = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
    let result = "";
    for (let i = length; i > 0; --i) result += chars[Math.floor(Math.random() * chars.length)];
    return result;
}