import { readFileSync, writeFileSync } from "fs";
import { resolve as r } from "path";

type WhitelistI = { uid: number, whitelisted: true };

export default class Whitelist {
    private static _instance: Whitelist;

    private constructor() { }

    public static get Instance(): Whitelist {
        return this._instance ??= new Whitelist();
    }

    public get(): WhitelistI[] {
        try {
            return JSON.parse(readFileSync(r(__dirname, "../../whitelist.json"), "utf8"));
        } catch {
            update([]);
            return [];
        }
    }

    public add(uid: number) {
        const whitelist = this.get();
        whitelist.push({ uid, whitelisted: true });
        update(whitelist);
    }

    public remove(uid: number) {
        const whitelist = this.get();
        const index = whitelist.findIndex(e => e.uid === uid);
        if (index !== -1) {
            whitelist.splice(index, 1);
            update(whitelist);
        }
    }

    public isWhitelisted(uid: number) {
        return this.get().find(e => e.uid === uid)?.whitelisted ?? false;
    }
}

function update(whitelist: WhitelistI[]): void {
    writeFileSync(r(__dirname, "../../whitelist.json"), JSON.stringify(whitelist, null, 4), "utf8");
}